@@ -1,9 +1,15 @@
 from PyObjCTools.TestSupport import TestCase, min_os_level
-import objc
 import MetalPerformanceShaders
 
 
 class TestMPSCore_MPSCoreTypes(TestCase):
+    def test_enum_types(self):
+        self.assertIsEnumType(MetalPerformanceShaders.MPSAliasingStrategy)
+        self.assertIsEnumType(MetalPerformanceShaders.MPSDataType)
+        self.assertIsEnumType(MetalPerformanceShaders.MPSImageEdgeMode)
+        self.assertIsEnumType(MetalPerformanceShaders.MPSImageFeatureChannelFormat)
+        self.assertIsEnumType(MetalPerformanceShaders.MPSKernelOptions)
+
     def test_constants(self):
         self.assertEqual(MetalPerformanceShaders.MPSKernelOptionsNone, 0)
         self.assertEqual(
@@ -46,6 +52,21 @@ class TestMPSCore_MPSCoreTypes(TestCase):
             MetalPerformanceShaders.MPSDataTypeFloat16,
             MetalPerformanceShaders.MPSDataTypeFloatBit | 16,
         )
+
+        self.assertEqual(MetalPerformanceShaders.MPSDataTypeComplexBit, 0x01000000)
+        self.assertEqual(
+            MetalPerformanceShaders.MPSDataTypeComplexFloat32,
+            MetalPerformanceShaders.MPSDataTypeFloatBit
+            | MetalPerformanceShaders.MPSDataTypeComplexBit
+            | 64,
+        )
+        self.assertEqual(
+            MetalPerformanceShaders.MPSDataTypeComplexFloat16,
+            MetalPerformanceShaders.MPSDataTypeFloatBit
+            | MetalPerformanceShaders.MPSDataTypeComplexBit
+            | 32,
+        )
+
         self.assertEqual(MetalPerformanceShaders.MPSDataTypeSignedBit, 0x20000000)
         self.assertEqual(
             MetalPerformanceShaders.MPSDataTypeIntBit,
@@ -115,39 +136,47 @@ class TestMPSCore_MPSCoreTypes(TestCase):
         self.assertIsInstance(v.x, int)
         self.assertIsInstance(v.y, int)
         self.assertIsInstance(v.z, int)
+        self.assertPickleRoundTrips(v)
 
         v = MetalPerformanceShaders.MPSOrigin()
         self.assertIsInstance(v.x, float)
         self.assertIsInstance(v.y, float)
         self.assertIsInstance(v.z, float)
+        self.assertPickleRoundTrips(v)
 
         v = MetalPerformanceShaders.MPSSize()
         self.assertIsInstance(v.width, float)
         self.assertIsInstance(v.height, float)
         self.assertIsInstance(v.depth, float)
+        self.assertPickleRoundTrips(v)
 
         v = MetalPerformanceShaders.MPSDimensionSlice()
         self.assertIsInstance(v.start, int)
         self.assertIsInstance(v.length, int)
+        self.assertPickleRoundTrips(v)
 
         v = MetalPerformanceShaders.MPSRegion()
         self.assertIsInstance(v.origin, MetalPerformanceShaders.MPSOrigin)
         self.assertIsInstance(v.size, MetalPerformanceShaders.MPSSize)
+        self.assertPickleRoundTrips(v)
 
         v = MetalPerformanceShaders.MPSScaleTransform()
         self.assertIsInstance(v.scaleX, float)
         self.assertIsInstance(v.scaleY, float)
         self.assertIsInstance(v.translateX, float)
         self.assertIsInstance(v.translateY, float)
+        self.assertPickleRoundTrips(v)
 
         v = MetalPerformanceShaders.MPSImageCoordinate()
         self.assertIsInstance(v.x, int)
         self.assertIsInstance(v.y, int)
         self.assertIsInstance(v.channel, int)
+        self.assertPickleRoundTrips(v)
 
         v = MetalPerformanceShaders.MPSImageRegion()
         self.assertIsInstance(v.offset, MetalPerformanceShaders.MPSImageCoordinate)
         self.assertIsInstance(v.size, MetalPerformanceShaders.MPSImageCoordinate)
+        self.assertPickleRoundTrips(v)
 
     @min_os_level("10.13")
     def test_functions10_13(self):
@@ -156,4 +185,4 @@ class TestMPSCore_MPSCoreTypes(TestCase):
         )
 
     def test_protocols(self):
-        objc.protocolNamed("MPSDeviceProvider")
+        self.assertProtocolExists("MPSDeviceProvider")
